==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SummaryRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
/**
 * @hidden
 */
var SummaryRowDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SummaryRowDescriptionMetadata, _super);
    function SummaryRowDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryRowDescriptionMetadata.b = function (a) {
        if (SummaryRowDescriptionMetadata.a == null) {
            SummaryRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryRowDescriptionMetadata.c(SummaryRowDescriptionMetadata.a);
        }
        if (a.k(SummaryRowDescriptionMetadata.a)) {
            return;
        }
        a.aa(SummaryRowDescriptionMetadata.a);
    };
    SummaryRowDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
        a.item("SelectedBackground", "Brush");
        a.item("ActualSelectedBackground", "Brush");
        a.item("SummaryLabelTextColor", "Brush");
        a.item("ActualSummaryLabelTextColor", "Brush");
        a.item("SummaryLabelFontFamily", "(w:SummaryLabelFontFamily/FontFamilyTransform,xam:SummaryLabelFontFamily,wf:SummaryLabelFontFamily,web:summaryNameTextStyle/FontFamilyTransform)String");
        a.item("SummaryLabelFontSize", "(w:SummaryLabelFontSize,xam:SummaryLabelFontSize,wf:SummaryLabelFontSize,web:summaryNameTextStyle/FontSizeTransform)Number:double");
        a.item("SummaryLabelFontStyle", "(w:SummaryLabelFontStyle/FontStyleTransform,xam:SummaryLabelFontFamily/FontStyleTransform,wf:SummaryLabelFontFamily/FontStyleTransform,web:summaryNameTextStyle/FontStyleTransform)String");
        a.item("SummaryLabelFontWeight", "(w:SummaryLabelFontWeight/FontWeightTransform,xam:SummaryLabelFontFamily/FontWeightTransform,wf:SummaryLabelFontFamily/FontWeightTransform,web:summaryNameTextStyle/FontWeightTransform)String");
        a.item("PaddingLeft", "Number:int");
        a.item("PaddingTop", "Number:int");
        a.item("PaddingRight", "Number:int");
        a.item("PaddingBottom", "Number:int");
    };
    SummaryRowDescriptionMetadata.d = function (a) {
        SummaryRowDescriptionMetadata.b(a);
        a.ab("SummaryRow", SummaryRowDescriptionMetadata.a);
    };
    SummaryRowDescriptionMetadata.$t = markType(SummaryRowDescriptionMetadata, 'SummaryRowDescriptionMetadata');
    SummaryRowDescriptionMetadata.a = null;
    return SummaryRowDescriptionMetadata;
}(Base));
export { SummaryRowDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/SummaryRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
/**
 * @hidden
 */
var SummaryRowDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SummaryRowDescriptionMetadata, _super);
    function SummaryRowDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryRowDescriptionMetadata.b = function (a) {
        if (SummaryRowDescriptionMetadata.a == null) {
            SummaryRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryRowDescriptionMetadata.c(SummaryRowDescriptionMetadata.a);
        }
        if (a.k(SummaryRowDescriptionMetadata.a)) {
            return;
        }
        a.ac(SummaryRowDescriptionMetadata.a);
    };
    SummaryRowDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
        a.item("SelectedBackground", "Brush");
        a.item("ActualSelectedBackground", "Brush");
        a.item("SummaryLabelTextColor", "Brush");
        a.item("ActualSummaryLabelTextColor", "Brush");
        a.item("SummaryLabelFontFamily", "(w:SummaryLabelFontFamily/FontFamilyTransform,xam:SummaryLabelFontFamily,wf:SummaryLabelFontFamily,web:summaryNameTextStyle/FontFamilyTransform)String");
        a.item("SummaryLabelFontSize", "(w:SummaryLabelFontSize,xam:SummaryLabelFontSize,wf:SummaryLabelFontSize,web:summaryNameTextStyle/FontSizeTransform)Number:double");
        a.item("SummaryLabelFontStyle", "(w:SummaryLabelFontStyle/FontStyleTransform,xam:SummaryLabelFontFamily/FontStyleTransform,wf:SummaryLabelFontFamily/FontStyleTransform,web:summaryNameTextStyle/FontStyleTransform)String");
        a.item("SummaryLabelFontWeight", "(w:SummaryLabelFontWeight/FontWeightTransform,xam:SummaryLabelFontFamily/FontWeightTransform,wf:SummaryLabelFontFamily/FontWeightTransform,web:summaryNameTextStyle/FontWeightTransform)String");
        a.item("PaddingLeft", "Number:int");
        a.item("PaddingTop", "Number:int");
        a.item("PaddingRight", "Number:int");
        a.item("PaddingBottom", "Number:int");
    };
    SummaryRowDescriptionMetadata.d = function (a) {
        SummaryRowDescriptionMetadata.b(a);
        a.ad("SummaryRow", SummaryRowDescriptionMetadata.a);
    };
    SummaryRowDescriptionMetadata.$t = markType(SummaryRowDescriptionMetadata, 'SummaryRowDescriptionMetadata');
    SummaryRowDescriptionMetadata.a = null;
    return SummaryRowDescriptionMetadata;
}(Base));
export { SummaryRowDescriptionMetadata };
